# `testPyPiPP` My simple project

* Opt1
* Opt2

## Install

```Python
pip install testPyPiPP
```

### Usage

```python
from testPyPiPP.m_mod_pp import name as n
from testPyPiPP.m_mod_pp import get_numpy_arr
>>> n('Name', 'Surname')
Name Surname
>>> get_numpy_arr([1,2,3,4,5])
[1 2 3 4 5]
```